.. title:: guilty

.. _guilty:

guilty
======

.. raw:: html

    <br>

both king netherlands and the 1st chamber wrote back to confirm their
informedness that what they call medication in their "care laws" is not
medication but poison. this makes the care laws not laws to give care to
elderly, handicapped, wicked and criminals but genocide laws where the
poison makes impotent, tortures to suicide and kills members of these groups.

law and medicine is taking care, law and poison is genocide.

.. raw:: html

    <br>

.. _chamber:

chamber
-------

.. raw:: html

  <br>

.. image:: kamer.png


.. raw:: html

    <br>

.. _king:

king
----

.. raw:: html

  <br>

.. image:: bevestigd.jpg

.. raw:: html

  <br>

